;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x9a361a26bdaf1655f62ff09530a880a5 . "./code.cg2js/cg-common-control.fasl")
(#xd0cd0299a9cc5a824bf0c1afe843dbe5 . "./code.cg2js/cg-header-control.fasl")
(#xad95c003c17cdef80581822d62c410bc . "./code.cg2js/cg-clipboard-stack.fasl")
(#xb11f9e508e0402b0cd7a6f4e77455f34 . "./code.cg2js/cg-yes-no-string.fasl")
(#xb58d652c2587ba3a4fda0371f7a15cde . "./code.cg2js/cg-clipboard.fasl")
(#x6a574eee2dcb8f23bc4050fbbc89e110 . "./code.cg2js/cg-dde-utils.fasl")
(#xbe8779d7eb997a138b82ea198e5abf68 . "./code.cg2js/cg-editable-text.fasl")
(#x7fb0d8c0ed997708d646369b349eb197 . "./code.cg2js/cg-text-or-combo.fasl")
(#x036a646604c09c75320221a182a3de3c . "./code.cg2js/cg-picture-widget-palette.fasl")
(#xcf6fa1abf77beee2620746362db1cd5b . "./code.cg2js/cg-graphics-context.fasl")
(#xac92727ab8df756ce1359136c0e0f6e1 . "./code.cg2js/cg-choose-printer.fasl")
(#x4f0879fb7bdce0a88c0ece4156665f92 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#xa4fb85667566ad3b08bea3d19c619cf4 . "./code.cg2js/cg-edit-in-place.fasl")
(#xc7cca2f606f0535c41c1a61a4eee9099 . "./code.cg2js/cg-split-bar.fasl")
(#x6d2d04ba0f42df481db3a8da63e6615d . "./code.cg2js/cg-timer.fasl")
(#xe281575d4e62345ce47e9908b0421972 . "./code.cg2js/cg-progress-indicator.fasl")
(#xa4dd2156b2287bb5e598f55fecbdd87c . "./code.cg2js/cg-object-editor.fasl")
(#xdfa28dae0b5faeb8dad7e1b3f58f48e3 . "./code.cg2js/cg-fill-texture.fasl")
(#x6b6ac19facabe82d75b3f64d70ac5845 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x876e8efab59b46beefbf6688a439c8ef . "./code.cg2js/cg-os-window.fasl")
(#x606ebfefb0f98271be42a0ab3184deb8 . "./code.cg2js/cg-color-dialog.fasl")
(#xc672acdcddff775945fd5d10358d1e7b . "./code.cg2js/cg-combo-box.fasl")
(#x4be686eaf56390653aa1bf47a1985577 . "./code.cg2js/cg-directory-dialog.fasl")
(#xe9703ca0f6ad5c5285c324074aee1e4b . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x4e4738ae6c0b543fa94257046627823c . "./code.cg2js/cg-tooltip.fasl")
(#x3f706cf113d4441673b14a0df1fbbced . "./code.cg2js/cg-lettered-menu.fasl")
(#xdc07bc2409f0d5c0b31bef29dc395f97 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x1bb513dc7bb1175918b88a3a0f43f5a3 . "./code.cg2js/cg-pixmap.fasl")
(#xf8f4c84a9b06134c68ca9a6fc5c3c747 . "./code.cg2js/cg.fasl")
(#x281bd116154d084bda41193ae5535ab1 . "./code.cg2js/cg-class-slot-grid.fasl")
(#xe6394dcf7c9623d8de7ae7b95f8d2b93 . "./code.cg2js/cg-template-string.fasl")
(#x2a33cbe2e18f6f1b644ffc07525246a2 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x1dcc1baf9357c05ce7a6564801235a93 . "./code.cg2js/cg-check-box.fasl")
(#x8c8e435255a6b0fb9547b8e6bf9af7c1 . "./code.cg2js/cg-toggling-widget.fasl")
(#x1acfd50cddc29de755a20103b63c0993 . "./code.cg2js/cg-radio-button.fasl")
(#x0b3384486d668f786c56409926a2074e . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x0c059782d7e4627470c41cafae2d9141 . "./code.cg2js/cg-scaling-stream.fasl")
(#x0096cb39b077fff3f16bb0b46686dff2 . "./code.cg2js/cg-multi-picture-button.fasl")
(#x7ab62063bd722418231a83088fbde60e . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x633e86a45a46f9bf4e5f6d6c3b973498 . "./code.cg2js/cg-grid-widget.fasl")
(#xa0b3726833c5f6c945c896578bee30eb . "./code.cg2js/cg-text-edit-pane.fasl")
(#x0036edb058f72833526b973e9610ea90 . "./code.cg2js/cg-item-list.fasl")
(#x35e55f492a249834431aa9e98fcbca22 . "./code.cg2js/cg-paren-matching.fasl")
(#x11ca6fff1a21ddf6c80b4c6f031d990d . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x3327ad05e7b09b729f12120023a3f621 . "./code.cg2js/cg-html-dialog.fasl")
(#x87531c90fb860cb725227b05ac4b5496 . "./code.cg2js/cg-pixmap-widget.fasl")
(#x730db7007e274f5a6153669c6815dd81 . "./code.cg2js/cg-project-window.fasl")
(#xdbf457cc65996ddd339f0c26435d771e . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x09ff9286a7fa6e0268dab961bf1cf576 . "./code.cg2js/cg-toolbar.fasl")
(#xea041385282235e015b25648f5247a2e . "./code.cg2js/cg-caret.fasl")
(#xc3e34caa05c4a77e60eee51c2d387b67 . "./code.cg2js/cg-scroll-bar.fasl")
(#xdd1cf02e17da5e96b87b263d7376b70f . "./code.cg2js/cg-web-browser.fasl")
(#x6b659d2b397609d0f7571fc788887fae . "./code.cg2js/cg-dropping-outline.fasl")
(#xa2d43b25728e13804a9bdcf7041dece4 . "./code.cg2js/cg-font-dialog.fasl")
(#xb5a27bbe0fa8f41cec981586efa87879 . "./code.cg2js/cg-icon-pixmap.fasl")
(#x6ce3f4822c6377bcf86674264cb2a230 . "./code.cg2js/cg-yes-no-list.fasl")
(#xdb071f4c7ef598f2ef115e05ddfa3210 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x16b2beb05337b8311cc37fcf03be5c7b . "./code.cg2js/cg-lamp.fasl")
(#xe2121b4b1fcd9210c7a2362b8b44d5c9 . "./code.cg2js/cg-drawable.fasl")
(#xafbeb89ead025653a2fd064c8869b247 . "./code.cg2js/cg-choice-list.fasl")
(#x555f2320f9dd54a517f87ffb1439d1f2 . "./code.cg2js/cg-curve.fasl")
(#x1551c0d3e5c9926a87cde32a933ef020 . "./code.cg2js/cg-base.fasl")
(#xa73ea4bebf83a8a17d6007a69a101587 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x59928c6beb68f68ce597f14aa6b9f544 . "./code.cg2js/cg-printing.fasl")
(#x597ef66d8d95680c779117f397e2cd48 . "./code.cg2js/cg-chart-or-plot.fasl")
(#x4e90f993caa035c19c0cbfe6fd4fb049 . "./code.cg2js/cg-hotspot.fasl")
(#x4489e409f0107976ab02d5183bd4f1c5 . "./code.cg2js/cg-object-editor-layout.fasl")
(#x569074b672abb925cd8ba83dd9c52b8b . "./code.cg2js/cg-utility-dialog.fasl")
(#x9100b4f44a18687699786316b0b68c80 . "./code.cg2js/cg-shortcut-menu.fasl")
(#xdcabffb004a9a0203ee42bf279df09a6 . "./code.cg2js/cg-comtab.fasl")
(#x7264c251952790393c5c29ef20b5a613 . "./code.cg2js/cg-os-widget.fasl")
(#x8d225445bcee3970f6f2653bbae240b0 . "./code.cg2js/cg-icon.fasl")
(#xc0b637dfe5b0d5090668e1ac81367c4e . "./code.cg2js/cg-dev.fasl")
(#xef3c2f902d888f471ce503ca2d8771b3 . "./code.cg2js/cg-calendar.fasl")
(#x433c52801feef09d252cb9174ba53036 . "./code.cg2js/cg-group-box.fasl")
(#x57ba020d2126d6363742fd22bfdabc77 . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#xeb90ca699afdc46f9910909e28ffedd9 . "./code.cg2js/cg-bitmap-pane.fasl")
(#xfd738f560923a023de84f0d24948c265 . "./code.cg2js/cg-drag-and-drop.fasl")
(#x93ad60a8f80e29b41bece7817427d700 . "./code.cg2js/cg-nodes.fasl")
(#xfd9b9ad28e6c44dd5e99fd4fcf9646f3 . "./code.cg2js/cg-intersect.fasl")
(#xdfde51f8ede57dfc516f6a22812e6561 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x21b7c2c746cbcfe0cde08613927e2a09 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#xca0815c5fec5c88561492c48d1d91e95 . "./code.cg2js/cg-class-support.fasl")
(#xedc861bd78d5433729d54003fa7cc140 . "./code.cg2js/cg-dialog-item.fasl")
(#xe61ab5f7e7a9726b84322add9f8f7277 . "./code.cg2js/cg-plot-widget.fasl")
(#xdb158c34617df51c1b582e460e32880e . "./code.cg2js/cg-pixmap-printing.fasl")
(#x4a81da5a7226117ca986116844bceaf3 . "./code.cg2js/cg-up-down-control.fasl")
(#x385fdc2088a6f08ff4517976d5b7b5eb . "./code.cg2js/cg-rich-edit.fasl")
(#x6d709d73ffd8c7bb7c4e2459ae5668f5 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x41c0302113c4190083d69036875d4d77 . "./code.cg2js/cg-status-bar.fasl")
(#xc709beecc5c8c303f7e5cc0d3d9cf0a3 . "./code.cg2js/cg-class-grid.fasl")
(#x77d0ead6df9dca557c698a9ffea67d82 . "./code.cg2js/cg-wrap-string.fasl")
(#xd61475ea1f4017fe7f10aa82d7503a1d . "./code.cg2js/cg-layout.fasl")
(#x89c801f94020184116ea62cad1f08868 . "./code.cg2js/cg-lisp-widget.fasl")
(#x5b2fff9a2c2e9b07a7ecaf980cb0179a . "./code.cg2js/cg-button.fasl")
(#x5051a70ebcfbe4665c3c6bae5f909e43 . "./code.cg2js/cg-string-dialog.fasl")
(#xcd5089518d7fe72798fd2793155f7d06 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x40d251f9d40a1c935aad360990c3d1e4 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#xc5f51b0cfe2e298b04e9b41d417b3319 . "./code.cg2js/cg-bitmap-stream.fasl")
(#xa023692f372bcb7b3864ff753a0bdf3a . "./code.cg2js/cg-static-text.fasl")
(#x0501cb5e4352cea156c48eb8e948e3f5 . "./code.cg2js/cg-outline.fasl")
(#x530b70ea13fac20dd25234032a21692f . "./code.cg2js/cg-gesture-emulation.fasl")
(#xe5b9dfb6dfcead023f3326239b117367 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x8747adb944c832edeafb43e10e1fc359 . "./code.cg2js/cg-picture-widget.fasl")
(#x3e1f70bd5f6b0aae28cd729f2d53412e . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x0012184e5ace6d5ca5cad2d742ae8528 . "./code.cg2js/cg-chart-widget.fasl")
(#x2850d12b39c57070c1c8588810075afa . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xfeb580ace3e13aa09162e57f33b49ec7 . "./code.cg2js/cg-lisp-text.fasl")
(#x87df748946fd8927c1eafd38264c5509 . "./code.cg2js/cg-palette.fasl")
(#xc62544a3e73e9e7529d3cffdbafc220d . "./code.cg2js/cg-property.fasl")
(#xcf4aed8c237c7037ccc795cdd4521fa8 . "./code.cg2js/cg-intersect-posbox.fasl")
(#xac1f206b37d8d87ff3921b046708cf3e . "./code.cg2js/cg-file-dialog.fasl")
(#x237cadef87eebae49b80d64f96e1db57 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#xcbd4a0bf7c049bb3718e99878f522ee2 . "./code.cg2js/cg-get-pixmap.fasl")
(#xef445e90602008533269f9a7a78a7bf6 . "./code.cg2js/cg-tray.fasl")
(#x8740ca73f6eb80040f134f9de8da96f5 . "./code.cg2js/cg-acache.fasl")
(#x2ee6604b658de9ac772375b0019205ae . "./code.cg2js/cg-message-dialog.fasl")
(#x824804a2bd40670074f8e4f50e048568 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#x815fcd8ce896e20aafb048eab1469516 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x38d118c2bfb5a0fe03499fbe768dfb6b . "./code.cg2js/cg-tab-control.fasl")
(#xac06e8125f7a350c6ac4933dd21bb8b3 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x9a217f69dfcf3778ea756ed86c4ffc04 . "./code.cg2js/cg-menu-tooltip.fasl")
(#xf484980a8f01d63e8e3fdc0b88bca14c . "./code.cg2js/cg-find-string-dialog.fasl")
(#x6657ef65f4e3f54064a35c56e054c3d4 . "./code.cg2js/cg-menu.fasl")
(#x33f4edcfe78b46b2c653b7a23745b338 . "./code.cg2js/cg-get-position.fasl")
(#xbaabfa3e059eb18e5decb93e54b3f0bd . "./code.cg2js/cg-trackbar.fasl")
(#x98a08b00971247087e5480bb8726d3f7 . "./code.cg2js/cg-selected-object.fasl")
(#xad444f8a94261f7d9d1d3383b18476ea . "./code.cg2js/cg-list-view.fasl")
(#x4d729092323de1dfa8682205107c8883 . "./code.cg2js/cg-html-widget.fasl")
(#xdcec3785a37e6493d68974fc0027edb5 . "./code.cg2js/cg-sample-file-menu.fasl")
(#x96fb4b380a008de61ec62f43a53748ea . "./code.cg2js/cg-text-widget.fasl")
(#x8c4f16762cf38f4952717c443d98881d . "./code.idejs/ide-base.fasl")
(#xbb6c93564f30efc7c1c99af42b0eae7f . "./code.idejs/ide-process-browser.fasl")
(#x8108d5aa24cf74d77d463735a1603cc4 . "./code.idejs/ide-patch-dialog.fasl")
(#xda1e158ab8ee5584787377a285892e7d . "./code.idejs/ide-keyshort.fasl")
(#x14b95a7d3f37258559760c2872099997 . "./code.idejs/ide-window-list.fasl")
(#x355e5b0c536b72967978f0c53a31a305 . "./code.idejs/ide.fasl")
(#x205734f526d06ff9c372baad7e9d0c33 . "./code.idejs/ide-editor.fasl")
(#x8a1feac27d4e539b5bf105fb7100b04a . "./code.idejs/ide-clipboard.fasl")
(#x5c427a88ba4cb323e3149ef8db609489 . "./code.idejs/ide-trace.fasl")
(#xfee9192db69dd1aadf275e13e433ebd7 . "./code.idejs/ide-class-browser.fasl")
(#x1f6bdcf05d720b0dd4c7c58680d0ba83 . "./code.idejs/ide-grapher.fasl")
(#x453902247b92c7cbfaffe3b6eaec4d22 . "./code.idejs/ide-apropos.fasl")
(#x2f43fcef47265d8be2ca8620803fb2ad . "./code.idejs/ide-navigator.fasl")
(#x1e91b1d5a5ebef2e58ce691ad3a1f361 . "./code.idejs/ide-find-definitions.fasl")
(#x3f3bb0f93818d68729267508c916563c . "./code.idejs/ide-project.fasl")
(#x0a700b184795e49d27b29839742569dc . "./code.idejs/ide-class-grapher.fasl")
(#x7756f7b964d0b0b6695e58b24083edba . "./code.idejs/ide-acache.fasl")
(#xb38123afbe5f62457171474be29b9d1e . "./code.idejs/ide-find-in-files.fasl")
(#xb2c0738defaf3eb85d2e0457d3bb5e70 . "./code.idejs/ide-inspector.fasl")
(#x61afdf55ef71b44c57901f2188d69659 . "./code.idejs/ide-intro.fasl")
(#xf1764b0d32b86f6056d04c850c891441 . "./code.idejs/ide-package-list.fasl")
(#x6a1652b2420de2be50f18557f1518344 . "./code.idejs/ide-dev.fasl")
(#xa0bc7d4e48e788fafd7651e21a169501 . "./code.idejs/ide-form.fasl")
(#xeb5b70ef6a4ced03becd92b82d3b0061 . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
